@@ -4,7 +4,7 @@ use 5.006001;
 use strict;
 use warnings;
 
-our $VERSION = '1.002';
+our $VERSION = '1.003';
 
 
 1; # Magic true value required at end of module
@@ -21,7 +21,7 @@ Task::Perl::Critic::IncludingOptionalDependencies - Install everything Perl::Cri
 =head1 VERSION
 
 This document describes
-Task::Perl::Critic::IncludingOptionalDependencies version 1.2.0.
+Task::Perl::Critic::IncludingOptionalDependencies version 1.3.0.
 
 
 =head1 SYNOPSIS
@@ -35,6 +35,14 @@ This module does nothing but act as a placeholder.  See L<Task>.
 
 Inspired by a question at the Perl::Critic BoF at OSCON 2007.
 
+B<WARNING>: Installing this distribution will install Policies that
+directly conflict with each other.  If you do not use a
+F<.perlcriticrc> file, and your severity is set high enough, there is
+no way for your code to not have violations.  A specific example:
+L<Perl::Critic::Policy::Compatibility::ProhibitThreeArgumentOpen> and
+L<Perl::Critic::Policy::InputOutput::ProhibitTwoArgOpen> directly
+contradict each other.
+
 
 =head1 INTERFACE
 
@@ -56,16 +64,10 @@ configuration files or environment variables.
 
 L<Task::Perl::Critic>
 
-L<ExtUtils::Manifest>
-
 L<File::HomeDir>
 
-L<File::Temp>
-
 L<File::Which>
 
-L<IO::String>
-
 L<IPC::Open2>
 
 L<Perl::MinimumVersion>
